@@ -34,8 +34,7 @@ class Preprocessor:
             tokens = [t for t in tokens if not len(t) < 4]
             tokens = [t for t in tokens if t in self._vocab]
         else:
-            tokens = tokens.split("")
-            tokens = [t for t in tokens if not len(t) < 4]
+            tokens = tokens.split(" ")
         return tokens 
 
     def to_bow(self, text, lemma):
@@ -157,7 +156,7 @@ def initialize_model(path_corpus,path_model,path_model_vocab,n):
     global concepts
     if esa_matrix == None and concepts == None:
         p = Preprocessor(path_model_vocab)
-        preprocessed = p.preprocess(path_corpus, lemma = True)
+        preprocessed = p.preprocess(path_corpus, lemma = False)
         concepts = tuple(preprocessed.keys())
         bows = tuple([preprocessed[bow] for bow in preprocessed])
         terms = tuple(set([word for bow in bows for word in bow]))
@@ -190,7 +189,7 @@ def model_topic(path_corpus,path_model,path_model_vocab,text,n):
     global esa_matrix
     global model
     global concepts
-    doc_prep = p.to_bow(text, lemma = True)
+    doc_prep = p.to_bow(text, lemma = False)
     document_vec = doc_to_vec(doc_prep)
     result = {}
     for concept in concepts:
